!
!  *******  Error function subroutine  *******
!   Numerical integration by trapezoid method 
!
      subroutine derrfunc( eta1,  eta2,  derfy, n )

      implicit none

      real(8)::  eta1,eta2
      real(8)::  x,x1,x2,dx
      real(8)::  s1,sall
      real(8)::  derfy
      real(8)::  pi,rootpi
      real(8), allocatable::  f(:)
      integer:: i,n

!  ****  number and width of trapezoids  ****

      x1 = eta1
      x2 = eta2

      dx = ( x2-x1 ) / dfloat( n )

!  ****  Value of function to be integrated  ****

      allocate ( f(0:n) )

      do i = 0,n
        x = x1 + dx * dfloat(i)
        f(i) = exp( - x**2 )
      end do

!  ****  integration  ****

      s1 = 0.0d0
      do i = 1,n-1
        s1 = s1 + 2.0d0*f(i)
      end do
      
      sall = dx * 0.5d0  * ( f(0) + s1 + f(n) )

!  ****  error function  ****

      pi = 4.0d0 * atan( 1.0d0 )
      rootpi = sqrt( pi )
      derfy = 2.0d0 / rootpi * sall
      
      return 
      end subroutine derrfunc

