! **********************************************************************
! *                                                                    *
! *     1-D Half-space cooling model for plate thermal evolution       *
! *                                                                    *
! **********************************************************************

      program hcm1_main
      implicit none

      real(8):: rho,Cp,ak,D
      real(8):: age,T0,TM
      real(8):: zk,z,zmax,dz,dzk,t
      real(8):: eta1,eta2,erfy,derfy
      real(8), allocatable:: Tmp(:)
      integer:: nz,j,ntra
      character(40):: apara,outfile

!  *****  read parameters  *****

!  Open parameter file

      open ( 10, file = 'pl_para.dat' )

!  read file 

      read (10,*) apara
      read (10,*) outfile
      write (6,*) apara,' = ',outfile

      read (10,*) apara
      read (10,*) rho
      write (6,*) apara,' = ',rho

      read (10,*) apara
      read (10,*) Cp
      write (6,*) apara,' = ',Cp

      read (10,*) apara
      read (10,*) ak
      write (6,*) apara,' = ',ak

      read (10,*) apara
      read (10,*) age
      write (6,*) apara,' = ',age

      read (10,*) apara
      read (10,*) T0
      write (6,*) apara,' = ',T0

      read (10,*) apara
      read (10,*) TM
      write (6,*) apara,' = ',TM

      read (10,*) apara
      read (10,*) dzk
      write (6,*) apara,' = ',dzk

      read (10,*) apara
      read (10,*) zmax
      write (6,*) apara,' = ',zmax

      read (10,*) apara
      read (10,*) ntra
      write (6,*) apara,' = ',ntra

!  convert unit km -> m, Ma -> sec

      dz   = dzk  * 1.0d3
      t    = age  * 1.0d6 * 365.2422d0 * 24.0d0 * 3600.0d0

!  thermal diffusivity

      D = ak / ( rho*Cp )

!  *****  nz: number of z points  ****

      nz = int( zmax / dzk + 0.5d0 )

!  allocate dimension variables

      allocate ( Tmp(0:nz) )

!  ******  calculate error function  ******

!  at the surface

      Tmp(0) = T0
      eta1 = 0.0d0
      erfy  = 0.0d0

!  at z = dz to zmax

      do j = 1,nz
        z = dz * dfloat( j )

!  eta = z / 2*(D*t)**(1/2) ****

        eta2 = 0.5d0 * z / sqrt( D*t )

!  error function
 
        call     derrfunc( eta1,  eta2,  derfy, ntra ) 
        erfy = erfy + derfy 

!  Temperature 

        Tmp(j) = T0 + ( TM-T0 ) * erfy

        eta1 = eta2
!        write (6,*) z,Tmp(j),erfy

      end do

!   *****  Output results to a file


!  Open a new file to save result

      open ( 20, file = outfile,status='new' )

!  write to file

      do j = 0,nz
        zk = dzk * dfloat( j )
        write (20,*) zk,Tmp(j)
      end do

!  close files 

      close (10)
      close (20)

      stop
      end program hcm1_main

